@@ -25,20 +25,26 @@ def cat_count(anns, names, show_count=False, save=False):
     # This should be done at the start
     for ann, name, ax in zip(anns, names, axes):
         ann_df = pd.DataFrame(ann.anns).transpose()
-        if 'category_name' in ann_df.columns:
-            chart = sns.countplot(data=ann_df,
-                                  x='category_name',
-                                  order=ann_df['category_name'].value_counts().index,
-                                  palette='Set1',
-                                  ax=ax)
+        if "category_name" in ann_df.columns:
+            chart = sns.countplot(
+                data=ann_df,
+                x="category_name",
+                order=ann_df["category_name"].value_counts().index,
+                palette="Set1",
+                ax=ax,
+            )
         else:
             # Add a new column -> category name
-            ann_df['category_name'] = ann_df.apply(lambda row: ann.cats[row.category_id]['name'],axis=1)
-            chart = sns.countplot(data=ann_df,
-                                  x='category_name',
-                                  order=ann_df['category_name'].value_counts().index,
-                                  palette='Set1',
-                                  ax=ax)
+            ann_df["category_name"] = ann_df.apply(
+                lambda row: ann.cats[row.category_id]["name"], axis=1
+            )
+            chart = sns.countplot(
+                data=ann_df,
+                x="category_name",
+                order=ann_df["category_name"].value_counts().index,
+                palette="Set1",
+                ax=ax,
+            )
 
         chart.set_title(name)
         chart.set_xticklabels(chart.get_xticklabels(), rotation=90)
@@ -46,25 +52,24 @@ def cat_count(anns, names, show_count=False, save=False):
         if show_count is True:
             for p in chart.patches:
                 height = p.get_height()
-                chart.text(p.get_x() + p.get_width() / 2.,
-                           height + 0.9,
-                           height,
-                           ha="center")
+                chart.text(p.get_x() + p.get_width() / 2.0, height + 0.9, height, ha="center")
 
-    plt.suptitle('Instances per category', fontsize=14, fontweight='bold')
+    plt.suptitle("Instances per category", fontsize=14, fontweight="bold")
     plt.tight_layout()
 
     fig = plt.gcf()
     fig.set_size_inches(11, 11)
 
-    out_dir = os.path.join(os.getcwd(), 'results', 'plots')
+    out_dir = os.path.join(os.getcwd(), "results", "plots")
     if save is True:
         if os.path.exists(out_dir) is False:
             os.mkdir(out_dir)
-        plt.savefig(os.path.join(out_dir, "cat_dist" + ".png"),
-                    bbox_inches='tight',
-                    pad_inches=0,
-                    dpi=plt.gcf().dpi)
+        plt.savefig(
+            os.path.join(out_dir, "cat_dist" + ".png"),
+            bbox_inches="tight",
+            pad_inches=0,
+            dpi=plt.gcf().dpi,
+        )
 
     plt.show()
 
@@ -72,7 +77,7 @@ def cat_count(anns, names, show_count=False, save=False):
 def get_areas(ann):
     obj_areas = []
     for key in ann.anns:
-        obj_areas.append(ann.anns[key]['area'])
+        obj_areas.append(ann.anns[key]["area"])
     return obj_areas
 
 
@@ -92,10 +97,12 @@ def get_object_size_split(ann, areaRng):
     if areaRng != sorted(areaRng):
         raise AssertionError("Area ranges incorrectly provided")
 
-    small    = len(ann.getAnnIds(areaRng=[(areaRng[0]**2), areaRng[1]**2]))
-    medium   = len(ann.getAnnIds(areaRng=[(areaRng[1]**2), areaRng[2]**2]))
-    large    = len(ann.getAnnIds(areaRng=[(areaRng[2]**2), areaRng[3]**2]))
-    left_out = len(ann.getAnnIds(areaRng=[0**2, (areaRng[0]**2)])) + len(ann.getAnnIds(areaRng=[areaRng[3]**2, (1e5**2)]))
+    small = len(ann.getAnnIds(areaRng=[(areaRng[0] ** 2), areaRng[1] ** 2]))
+    medium = len(ann.getAnnIds(areaRng=[(areaRng[1] ** 2), areaRng[2] ** 2]))
+    large = len(ann.getAnnIds(areaRng=[(areaRng[2] ** 2), areaRng[3] ** 2]))
+    left_out = len(ann.getAnnIds(areaRng=[0 ** 2, (areaRng[0] ** 2)])) + len(
+        ann.getAnnIds(areaRng=[areaRng[3] ** 2, (1e5 ** 2)])
+    )
 
     logging.debug("Number of small objects in set = %s", small)
     logging.debug("Number of medium objects in set = %s", medium)
@@ -117,23 +124,22 @@ def pi_area_split_single(ann, areaRng):
 
     if left_out != 0:
         sizes = [small, large, left_out, medium]
-        labels = 'Small', 'Large', 'Ignored', 'Medium'
-        colors = ['#ff9999', '#66b3ff', '#99ff99', '#ffcc99']
+        labels = "Small", "Large", "Ignored", "Medium"
+        colors = ["#ff9999", "#66b3ff", "#99ff99", "#ffcc99"]
     else:
         sizes = [small, large, medium]
-        labels = 'Small', 'Large', 'Medium'
-        colors = ['#ff9999', '#66b3ff', '#ffcc99']
-
+        labels = "Small", "Large", "Medium"
+        colors = ["#ff9999", "#66b3ff", "#ffcc99"]
 
     _, ax1 = plt.subplots()
-    ax1.pie(sizes, colors=colors, labels=labels, autopct='%1.2f%%', startangle=90)
-    #draw circle
-    centre_circle = plt.Circle((0, 0), 0.70, fc='white')
+    ax1.pie(sizes, colors=colors, labels=labels, autopct="%1.2f%%", startangle=90)
+    # draw circle
+    centre_circle = plt.Circle((0, 0), 0.70, fc="white")
     fig = plt.gcf()
     fig.gca().add_artist(centre_circle)
     # Equal aspect ratio ensures that pie is drawn as a circle
-    ax1.axis('equal')
-    plt.title('Object Size Distribution', fontsize=14, fontweight='bold', pad=20)
+    ax1.axis("equal")
+    plt.title("Object Size Distribution", fontsize=14, fontweight="bold", pad=20)
     plt.tight_layout()
     plt.show()
 
@@ -147,12 +153,12 @@ def pi_area_split(anns, names, areaRng, save=False):
 
         if left_out != 0:
             sizes = [small, large, left_out, medium]
-            labels = 'Small', 'Large', 'Ignored', 'Medium'
-            colors = ['#ff9999', '#66b3ff', '#99ff99', '#ffcc99']
+            labels = "Small", "Large", "Ignored", "Medium"
+            colors = ["#ff9999", "#66b3ff", "#99ff99", "#ffcc99"]
         else:
             sizes = [small, large, medium]
-            labels = 'Small', 'Large', 'Medium'
-            colors = ['#ff9999', '#66b3ff', '#ffcc99']
+            labels = "Small", "Large", "Medium"
+            colors = ["#ff9999", "#66b3ff", "#ffcc99"]
 
         stuff.append([sizes, labels, colors])
 
@@ -160,25 +166,25 @@ def pi_area_split(anns, names, areaRng, save=False):
 
     for s, name, ax in zip(stuff, names, axs.flat):
         ax.clear()
-        ax.pie(s[0], labels=s[1], colors=s[2], autopct='%1.2f%%', startangle=90)
-        #draw circle
-        #centre_circle = plt.Circle((0, 0), 0.70, fc='white')
-        #fig = plt.gcf()
-        #fig.gca().add_artist(centre_circle)
+        ax.pie(s[0], labels=s[1], colors=s[2], autopct="%1.2f%%", startangle=90)
+        # draw circle
+        # centre_circle = plt.Circle((0, 0), 0.70, fc='white')
+        # fig = plt.gcf()
+        # fig.gca().add_artist(centre_circle)
         # Equal aspect ratio ensures that pie is drawn as a circle
-        #ax.axis('equal')
-        #from matplotlib import rcParams
-        #rcParams['axes.titlepad'] = 100
+        # ax.axis('equal')
+        # from matplotlib import rcParams
+        # rcParams['axes.titlepad'] = 100
         ax.set_title(name)
 
-    #plt.title('Object Size Distribution', pad=20)
-    fig.suptitle("Object Size Distribution", fontsize=14, fontweight='bold')
-    #plt.tight_layout()
+    # plt.title('Object Size Distribution', pad=20)
+    fig.suptitle("Object Size Distribution", fontsize=14, fontweight="bold")
+    # plt.tight_layout()
 
-    #fig = plt.gcf()
-    #fig.set_size_inches(11,11)
+    # fig = plt.gcf()
+    # fig.set_size_inches(11,11)
 
-    out_dir = os.path.join(os.getcwd(), 'results','plots')
+    out_dir = os.path.join(os.getcwd(), "results", "plots")
 
     if save is True:
         if os.path.exists(out_dir) is False:
@@ -190,18 +196,18 @@ def pi_area_split(anns, names, areaRng, save=False):
 if __name__ == "__main__":
     # Get Annotations Dir and Image folder
     folder1 = "test1"
-    annFile1 = os.path.join(os.getcwd(), 'annotations', "{}.json".format(folder1))
+    annFile1 = os.path.join(os.getcwd(), "annotations", "{}.json".format(folder1))
     ann1 = COCO(annFile1)
 
     folder2 = "test2"
-    annFile2 = os.path.join(os.getcwd(), 'annotations', "{}.json".format(folder2))
+    annFile2 = os.path.join(os.getcwd(), "annotations", "{}.json".format(folder2))
     ann2 = COCO(annFile2)
 
     folder3 = "test3"
-    annFile3 = os.path.join(os.getcwd(), 'annotations', "{}.json".format(folder3))
+    annFile3 = os.path.join(os.getcwd(), "annotations", "{}.json".format(folder3))
     ann3 = COCO(annFile3)
 
-    #cat_count(ann, folder, show_count=True)
-    #pi_area_split(ann, areaRng=[0, 144, 512, 1e5])
-    #pi_area_split_multi([ann1, ann2, ann3], folders=[folder1, folder2, folder3], areaRng=[10, 144, 512, 1e5])
-    #view_area_dist(ann)
+    # cat_count(ann, folder, show_count=True)
+    # pi_area_split(ann, areaRng=[0, 144, 512, 1e5])
+    # pi_area_split_multi([ann1, ann2, ann3], folders=[folder1, folder2, folder3], areaRng=[10, 144, 512, 1e5])
+    # view_area_dist(ann)
